.. currentmodule:: sardana.pool.pooltwodexpchannel

.. _sardana-2d-api:

=============================
2D channel API reference
=============================

.. todo:: document 2D channel API reference

.. seealso:: 
    
    :ref:`sardana-2d-overview`
        the 2D experiment channel overview 
    
    :class:`~sardana.tango.pool.TwoDExpChannel.TwoDExpChannel`
        the 2D experiment channel tango device :term:`API`

..    :class:`~sardana.pool.pooltwodexpchannel.Pool2DExpChannel`
..        the 2D experiment channel class :term:`API`
